require "spec_helper"

describe Namesplit do
  it "returns an empty Hash if no string or empty string is given" do
    expect(Namesplit.split(nil).first_names).to eq(nil)
    expect(Namesplit.split(nil).first_name).to eq(nil)
    expect(Namesplit.split(nil).last_name).to eq(nil)
  end

  it "detects uppercasing 1/3" do
    input = "Jfbkzebfz OVUIFVEEI"
    expect(Namesplit.split(input).first_names).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).first_name).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).last_name).to eq("Ovuifveei")
  end

  it "detects uppercasing 2/3" do
    input = "OVUIFVEEI jfbkzebfz"
    expect(Namesplit.split(input).first_names).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).first_name).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).last_name).to eq("Ovuifveei")
  end

  it "detects uppercasing 3/3" do
    input = "DE OVUIFVEEI jfbkzebfz"
    expect(Namesplit.split(input).first_names).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).first_name).to eq("Jfbkzebfz")
    expect(Namesplit.split(input).last_name).to eq("De Ovuifveei")
  end

  it "works with the simplest of cases" do
    input = "Albert Einstein"
    expect(Namesplit.split(input).first_names).to eq("Albert")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("Einstein")
  end

  it "works with the simplest of cases" do
    input = "Albert D'Einstein-Goon"
    expect(Namesplit.split(input).first_names).to eq("Albert")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("D'Einstein-Goon")
  end

  it "works with the simple case with two words last name" do
    input = "Albert De Einstein"
    expect(Namesplit.split(input).first_names).to eq("Albert")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("De Einstein")
  end

  it "with mutliple first names 1/2" do
    input = "Albert Thomas Jacques Einstein"
    expect(Namesplit.split(input).first_names).to eq("Albert Thomas Jacques")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("Einstein")
  end

  it "with mutliple first names 2/2" do
    input = "Einstein Albert Thomas Jacques"
    expect(Namesplit.split(input).first_names).to eq("Albert Thomas Jacques")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("Einstein")
  end

  it "cleans the punctuation" do
    input = "Albert, Einstein!"
    expect(Namesplit.split(input).first_names).to eq("Albert")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("Einstein")
  end

  it "cleans the spaces" do
    input = "Albert   Einstein  "
    expect(Namesplit.split(input).first_names).to eq("Albert")
    expect(Namesplit.split(input).first_name).to eq("Albert")
    expect(Namesplit.split(input).last_name).to eq("Einstein")
  end

  it "works with real data" do
    input = "BEAUMANOIRE (Pierre-Yves)"
    expect(Namesplit.split(input).first_names).to eq("Pierre-Yves")
    expect(Namesplit.split(input).first_name).to eq("Pierre-Yves")
    expect(Namesplit.split(input).last_name).to eq("Beaumanoire")
  end

  it "works with real data" do
    input = "Delorme - Thomas, Cécile Jeanne Marie"
    expect(Namesplit.split(input).first_names).to eq("Thomas Cécile Jeanne Marie")
    expect(Namesplit.split(input).first_name).to eq("Thomas")
    expect(Namesplit.split(input).last_name).to eq("Delorme")
  end

  it "works with real data" do
    input = "BERGES MANON, ANASTASIA, ANTOINETTE"
    expect(Namesplit.split(input).last_name).to eq("Berges")
    expect(Namesplit.split(input).first_names).to eq("Manon Anastasia Antoinette")
    expect(Namesplit.split(input).first_name).to eq("Manon")
  end

  it "works with real data" do
    input = "LE ROUX Sylvain, Marc, Denis"
    expect(Namesplit.split(input).first_names).to eq("Sylvain Marc Denis")
    expect(Namesplit.split(input).first_name).to eq("Sylvain")
    expect(Namesplit.split(input).last_name).to eq("Le Roux")
  end

  it "works with real data" do
    input = "FINCK Jean-Eric"
    expect(Namesplit.split(input).first_names).to eq("Jean-Eric")
    expect(Namesplit.split(input).first_name).to eq("Jean-Eric")
    expect(Namesplit.split(input).last_name).to eq("Finck")
  end

  it "works with real data" do
    input = "DUARTE PEREIRA DA COSTA Nelson Edgar"
    expect(Namesplit.split(input).first_names).to eq("Nelson Edgar")
    expect(Namesplit.split(input).first_name).to eq("Nelson")
    expect(Namesplit.split(input).last_name).to eq("Duarte Pereira Da Costa")
  end

  it "works with real data" do
    input = "ORTIZ-GOBO Didier Florent"
    expect(Namesplit.split(input).first_names).to eq("Didier Florent")
    expect(Namesplit.split(input).first_name).to eq("Didier")
    expect(Namesplit.split(input).last_name).to eq("Ortiz-Gobo")
    expect(Namesplit.split(input).full_name).to eq("Ortiz-Gobo Didier Florent")
  end
end
